<?php
/**
 * This class simply add fields to widget admin that allows you to:
 * - Add additional css class to it for further styling.
 * - Add option to hide widget title (most of default widgets does not do this)
 * - Add option to create theme-based tag cloud without affecting default one.
 *
 * @author  Stev Ngo <http://stevngodesign.com/>
 * @version 1.2
 * @package laboom
 * @since   laboom 1.0
 */

class WPHealthyFood_Widget_Extends
{
    /**
     * Construction
     */
    function __construct()
    {
        global $pagenow;

        if ( is_admin() )
        {
            add_action( 'in_widget_form', array( $this, 'extend_widget_form' ), 10, 3 );
            add_filter( 'widget_update_callback', array( $this, 'extend_widget_update' ), 10, 4 );
        }
        add_filter( 'dynamic_sidebar_params', array( $this, 'extend_widget_params'), 10, 2 );
    }


    /**
     * Adds form fields to the end of Widget form
     * 
     * @param   $widget     object  WP_Widget | The widget instance, passed by reference.
     * @param   $return     null    Return null if new fields are added.
     * @param   $instance   array   An array of the widget's settings.
     * @return  array               An array of the new widget's settings.
     */
    function extend_widget_form( $widget, $return, $instance )
    {
        if ( ! isset( $instance['sub_title'] ) )
        {
            $instance['sub_title'] = '';
        }
        ?>
        <p>
            <label for="widget-<?php echo esc_attr( $widget->id_base . '-' . $widget->number ); ?>-sub_title"><?php esc_html_e( 'Subtile', 'laboom' ); ?></label>
            <input type="text" class="widefat code" 
                name="widget-<?php echo esc_attr( $widget->id_base . '[' . $widget->number . '][sub_title]' ); ?>" 
                id="widget-<?php echo esc_attr( $widget->id_base . '-' . $widget->number ); ?>-sub_title" 
                value="<?php echo esc_attr( $instance['sub_title'] ); ?>" />
        </p>
        <?php

        
        return $instance;
    }


    /**
     * Add css class param to the widget before saving
     * 
     * @param   $instance       array   The current widget instance's settings.
     * @param   $new_instance   array   Array of new widget settings.
     * @return  array                   An array of the new widget's settings.
     */
    function extend_widget_update( $instance, $new_instance, $old_instance, $object )
    {
        $instance['sub_title'] = $new_instance['sub_title'];
        return $instance;
    }


    /**
     * Add css class to widget front-end display by filtering widget params
     * @param   $params array
     * @return  array   Extended widget parameters
     */
    function extend_widget_params( $params )
    {
        global $wp_registered_widgets;
        
        $widget_obj = $wp_registered_widgets[$params[0]['widget_id']];
        $widget_num = $widget_obj['params'][0]['number'];
        $instances = get_option( $widget_obj['callback'][0]->option_name );
        $instance = $instances[$widget_num];

        if ( ! empty( $instance['sub_title'] ) )
        {
            $old_bt = strlen( $params[0]['before_title'] ) ? $params[0]['before_title'] : '';
            $params[0]['before_title'] = '<span class="wg-subtitle">' . esc_html( $instance['sub_title'] ) . '</span>' . $old_bt;
        }

        return $params;
    }
}

new WPHealthyFood_Widget_Extends();